SAMMI Documentation
-------------------------

This is the documentation for the ``sammi`` Python Package.
For more information about the SAMMI project, please visit our GitHub page at `https://github.com/swxsoc/sammi <https://github.com/swxsoc/sammi>`_

.. toctree::
   :maxdepth: 2

   whatsnew/index
   user-guide/index
   dev-guide/index
   acknowledging
   api
